#!/usr/bin/env bash

# -e 遇到命令退出状态非0时立即退出
# -u 遇到变量不存在时立即退出
# -o pipefail 管道中任一命令失败立即退出
set -eo pipefail

# CPU架构
os_arch=$(uname -m)

# 针对首次运行和单独运行的脚本，根据os_system的存在判断安装脚本
if [[ -z $os_system ]]; then
    if [ -f /etc/os-release ]; then
        # 加载 /etc/os-release 文件内容
        source "/etc/os-release"

        # 转换系统名称为小写
        lower_id=$(echo "$ID" | tr '[:upper:]' '[:lower:]')

        if [[ "$lower_id" == "centos" || $ID_LIKE =~ "rhel" || $ID_LIKE =~ "fedora" ]]; then
            os_system="centos"
            install_cmd="yum install -y"
            local_install_cmd="yum localinstall -y"
            if [ -f /etc/redhat-release ]; then
                redhat_release=$(cat /etc/redhat-release)
                # 提取子版本号，如 7.6、7.9
                if [[ $redhat_release =~ ([0-9]+\.[0-9]+) ]]; then
                    os_version="${BASH_REMATCH[1]}"
                else
                    os_version="unknown"
                fi
            else
                os_version="unknown"
            fi
        elif [[ "$lower_id" == "kylin" ]]; then
            os_system="kylin"
            install_cmd="yum install -y"
            local_install_cmd="yum localinstall -y"
            # 如果是 Kylin，从 VERSION 提取括号内的版本名
            if [[ "$VERSION" =~ .+\((.+)\) ]]; then
                os_version=$(echo "${BASH_REMATCH[1]}" | tr '[:upper:]' '[:lower:]')
            else
                os_version="unknown"
            fi
        elif [[ "$lower_id" == "ubuntu" || $ID_LIKE =~ "debian" ]]; then
            os_system="ubuntu"
            install_cmd="apt-get install -y"
            local_install_cmd="dpkg -i"
            # 提取主版本号和子版本号，例如 24
            if [[ "$VERSION_ID" =~ ([0-9]+)\.([0-9]+) ]]; then
                os_version="${BASH_REMATCH[1]}"
            else
                os_version="unknown"
            fi
        else
            os_version="unknown"
        fi
    else
        printf "/etc/os-release doesn't exist ,Unsupported operating system! \n"
        exit 1
    fi
    os_full_name="${os_arch}-${os_system}-${os_version}"
    # 只根据初始化脚本是否存在判断能否继续安装
    if [ ! -f "init-env-$os_full_name.sh" ]; then
        printf "Cannot find the proper shell script to initialize environment! os_full_name: %s \n" "$os_full_name"
        exit 1
    fi
fi

# 脚本所在位置
sh_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &> /dev/null && pwd)
cd "$sh_dir"
root_dir=$(dirname "$sh_dir")

# 输出变量
export install_cmd
export local_install_cmd
export os_arch
export os_system
export os_version
export os_full_name
export root_dir

# 读取配置
source ./config
# 读取函数
source ./functions.sh
