#!/bin/bash

CONFIG_FILE="$1"
HOSTS_FILE="/etc/hosts"
DATE_TAG=$(date +'%Y-%m-%d')
START_MARKER="# HINA-CLOUD START EXPAND on $DATE_TAG"
END_MARKER="# HINA-CLOUD END EXPAND on $DATE_TAG"
TMP_FILE="hinadt_hosts_expand_${DATE_TAG}.txt"  # 创建带日期的临时文件
TMP_DIR="./tmp_hosts"  # 临时文件存放目录

# 确保临时文件存放目录存在
mkdir -p "$TMP_DIR"
: > "$TMP_DIR/$TMP_FILE"

# 查找 /etc/hosts 中的最大编号
sudo sed -i "/$START_MARKER/,/$END_MARKER/d" "$HOSTS_FILE" 
last_count=$(sudo grep -oP 'hina-cloud-\K\d+' "$HOSTS_FILE" | sort -n | tail -n 1)

# 如果没有找到任何 hinadt_hosts 记录，则从1开始
if [ -z "$last_count" ]; then
    count=1
else
    count=$((last_count + 1))
fi

# 读取配置文件并处理每一行
tail -n +2 "$CONFIG_FILE" | while IFS= read -r line || [[ -n "$line" ]]; do
    if [[ -z "$line" ]]; then
        continue
    fi

    first_field=$(echo "$line" | awk '{print $1}')
    
    if [[ "$first_field" =~ ^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$ ]]; then
        ip="$first_field"
    else
        ip=$(ping -c 1 "$first_field" 2>/dev/null | grep -oP '(?<=\()[\d\.]+(?=\))' | head -n 1)
        
        if [ -z "$ip" ]; then
            continue
        fi
    fi

    # 生成新的域名并保存到临时文件
    domain="hina-cloud-$count"
    echo "$ip $domain" >> "$TMP_DIR/$TMP_FILE"
    ((count++))
done

# 如果有新增的内容，更新 /etc/hosts 文件
if [ -s "$TMP_DIR/$TMP_FILE" ]; then
     
    echo -e "\n$START_MARKER" | sudo tee -a "$HOSTS_FILE" > /dev/null
    sudo cat "$TMP_DIR/$TMP_FILE" | sudo tee -a "$HOSTS_FILE" > /dev/null
    echo "$END_MARKER" | sudo tee -a "$HOSTS_FILE" > /dev/null
    echo "Expansion complete. Hosts file updated with expansion marker for $DATE_TAG!"
else
    echo "No new entries to add. Hosts file is already up to date."
fi

