#!/usr/bin/env bash

# 脚本所在位置
sh_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &> /dev/null && pwd)
cd $sh_dir
source ./base.sh

# 本机执行安装前检查
bash pre-install-system-check.sh

# 判断文件是否存在
if [[ ! -e $NODE_SSH_INFO || ! -f $NODE_SSH_INFO ]]; then
    echo "NODE_SSH_INFO does not exist or is not a file, can not handle node ssh authentication!"
    exit 1
fi

# 输出要初始化环境的节点信息
echo "Start to initialize environment in nodes below, first node will be the master node!"
retrieve_node_ssh_info 'echo $node_ip'

# 执行当前节点->集群的SSH认证互信（单向）
bash node-authentication.sh

# 执行主机名检查
# bash hostname-check-set.sh

echo "Count down 10 seconds, press Ctrl+C to interrupt execution!"
count_down 10

# 执行所有节点文件分发
bash node-distribute.sh

# 执行安装前检查
retrieve_node_ssh_info_in_background run_script_on_remote pre-install-system-check.sh

# 添加/etc/hosts
retrieve_node_ssh_info_in_background run_script_on_remote init-hosts.sh

# 执行所有节点初始化环境
retrieve_node_ssh_info_in_background run_script_on_remote init-env-${os_full_name}.sh

# 等待30秒
echo "To make sure all cluster nodes are ready, wait 30 seconds..."
count_down 30

# 执行主节点初始化后续步骤
handle_first_node_ssh_info run_script_on_remote init-master.sh

