#!/bin/bash

# 脚本所在位置
sh_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &> /dev/null && pwd)
cd $sh_dir
source ./base.sh

# -----------------系统设置
sudo modprobe br_netfilter
sudo lsmod | grep br_netfilter
echo "br_netfilter" | sudo tee /etc/modules-load.d/br_netfilter.conf

# 临时禁用swap
sudo swapoff -a
# 临时修改限制
sudo bash -c 'ulimit -n 1000000'
# 临时修改内存区域
sudo sysctl -w vm.max_map_count=2000000
# 临时关闭透明大页
sudo sh -c "echo never > /sys/kernel/mm/transparent_hugepage/enabled"
sudo sh -c "echo never > /sys/kernel/mm/transparent_hugepage/defrag"

# 安装containerd
containerd_dir=$CONTAINERD_PACKAGE_DIR
containerd_config=$containerd_dir/config
sudo yum localinstall --disablerepo=* -y $containerd_dir/dependencies/*.rpm
sudo yum localinstall --disablerepo=* -y $containerd_dir/*.rpm
sudo systemctl daemon-reload
sudo systemctl enable --now containerd

# 配置containerd
sudo mkdir -p /etc/containerd
sudo containerd config default | sed 's|sandbox_image = "registry\.k8s\.io/pause:.*"|sandbox_image = "registry.k8s.io/pause:3.9"|' \
  | sudo tee /etc/containerd/config.toml
sudo systemctl restart containerd.service

# -----------------加载k8s镜像

bash load-docker-images.sh

# -----------------安装k8s
printf "====================== $KUBERNETES_PACKAGE_DIR"
k8s_dir=$KUBERNETES_PACKAGE_DIR
sudo yum localinstall --disablerepo=* -y $k8s_dir/dependencies/*.rpm
sudo yum localinstall --disablerepo=* -y $k8s_dir/*.rpm

# 配置 crictl
cat $containerd_config/crictl.yaml | sudo tee /etc/crictl.yaml

# 重加载k8s配置，并设置开机启动
sudo systemctl daemon-reload
sudo systemctl enable --now kubelet

# 创建数据目录
sudo mkdir -p /opt/edp
sudo chmod -R 777 /opt/edp
sudo chown -R $(id -u):$(id -g) /opt/edp
sudo mkdir -p /data