#!/bin/bash

# 脚本所在位置
sh_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &> /dev/null && pwd)
cd $sh_dir
source ./base.sh

# 重要：该脚本运行前，必须提前做好互信
# -----------------系统设置
sudo modprobe br_netfilter
sudo lsmod | grep br_netfilter
echo "br_netfilter" | sudo tee /etc/modules-load.d/br_netfilter.conf

# 临时禁用swap
sudo swapoff -a
# 临时修改限制
sudo bash -c 'ulimit -n 1000000'
# 临时修改内存区域
sudo sysctl -w vm.max_map_count=2000000
# 临时关闭透明大页
sudo sh -c "echo never > /sys/kernel/mm/transparent_hugepage/enabled"
sudo sh -c "echo never > /sys/kernel/mm/transparent_hugepage/defrag"

# -----------------安装containerd
containerd_dir=$CONTAINERD_PACKAGE_DIR
containerd_config=$containerd_dir/config

# install containerd
sudo tar Cxzvf /usr/local $containerd_dir/containerd-1.7.0-linux-amd64.tar.gz
cat $containerd_config/containerd.service | sudo tee /usr/lib/systemd/system/containerd.service 
sudo systemctl daemon-reload
sudo systemctl enable --now containerd


# install runc
sudo install -m 755 $containerd_dir/runc.amd64 /usr/local/sbin/runc

# install cni
sudo mkdir -p /opt/cni/bin
sudo tar Cxzvf /opt/cni/bin $containerd_dir/cni-plugins-linux-amd64-v1.2.0.tgz
sudo rm -rf /etc/cni/net.d/*

# install crictl
sudo tar Czxvf /usr/local/bin $containerd_dir/crictl-v1.28.0-linux-amd64.tar.gz 

# 配置containerd
sudo mkdir -p /etc/containerd && sudo rm -rf /etc/containerd/config.toml
sudo cp $containerd_config/config.toml /etc/containerd/config.toml
sudo systemctl restart containerd.service

# 配置 crictl
cat $containerd_config/crictl.yaml | sudo tee /etc/crictl.yaml

# -----------------加载k8s镜像

bash load-docker-images.sh

# -----------------安装k8s
k8s_dir=$KUBERNETES_PACKAGE_DIR
sudo yum localinstall --disablerepo=* -y $k8s_dir/dependencies/*.rpm
sudo yum localinstall --disablerepo=* -y $k8s_dir/*.rpm

# 重加载k8s配置，并设置开机启动
sudo systemctl daemon-reload
sudo systemctl enable --now kubelet

# 创建数据目录
sudo mkdir -p /opt/edp
sudo chmod -R 777 /opt/edp
sudo chown -R $(id -u):$(id -g) /opt/edp
sudo mkdir -p /data