#!/usr/bin/env bash

# 脚本所在位置
sh_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &> /dev/null && pwd)
cd $sh_dir
source ./base.sh

# 安装containerd
if [[ -z $(command -v ctr) ]]; then
    install_package "$CONTAINERD_PACKAGE_DIR" "$CONTAINERD_VERSION"
fi

# 重加载docker配置，并设置开机启动
sudo systemctl daemon-reload
sudo systemctl enable --now docker

# 设定镜像仓库地址
cat << EOF | sudo tee /etc/docker/daemon.json
{
    "exec-opts":
    [
        "native.cgroupdriver=systemd"
    ]
}
EOF

# 重启docker
sudo systemctl restart docker
sudo docker info


# 加载本地docker镜像
bash load-docker-images.sh

# 安装kubernetes
if [[ -z $(command -v kubectl) || -z $(command -v kubeadm) || -z $(command -v kubelet) ]]; then
    install_package $KUBERNETES_PACKAGE_DIR $KUBERNETES_VERSION
fi
# 重加载k8s配置，并设置开机启动
sudo systemctl daemon-reload
sudo systemctl enable --now kubelet

sudo mkdir -p /opt/edp
sudo chmod -R 777 /opt/edp
sudo chown -R $(id -u):$(id -g) /opt/edp

sudo mkdir -p /data

echo "Current node environment initialization is complete!"