#!/bin/bash

# 脚本所在位置
sh_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &> /dev/null && pwd)
cd $sh_dir
source ./base.sh

CONFIG_FILE="$NODE_SSH_INFO"
HOSTS_FILE="/etc/hosts"
DATE_TAG=$(date +'%Y-%m-%d')
START_MARKER="# HINA-CLOUD START INIT on $DATE_TAG"
END_MARKER="# HINA-CLOUD END INIT on $DATE_TAG"
TMP_FILE="hinadt_hosts_init_${DATE_TAG}.txt"  
TMP_DIR="./tmp_hosts"
IPV4_REGEX="^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+$"
LOCAL_IP=$(ping -c 1 "$(hostname)" 2>/dev/null | grep -oP '(?<=\()[\d\.]+(?=\))' | head -n 1)

# 确保临时文件存放目录存在
mkdir -p "$TMP_DIR"
: > "$TMP_DIR/$TMP_FILE"
count=1

set_hostname() {
    if [[ "$node_ip" =~ "$IPV4_REGEX" ]]; then
        ip="$node_ip"
    else
        ip=$(ping -c 1 "$node_ip" 2>/dev/null | grep -oP '(?<=\()[\d\.]+(?=\))' | head -n 1)
        
        if [ -z "$ip" ]; then
            continue
        fi
    fi

    # 生成新的主机名并保存到临时文件
    new_hostname="hina-cloud-$count"
    # 对于已经设置过主机名的节点，如果之前hosts文件中已经设置过其他节点的IP映射，则仍然保留
    if [[ "$LOCAL_IP" = "$ip" ]]; then
        # 考虑这样一种情况：之前hosts文件中没有设置IP映射，但是本机上存在两个服务通过主机名互相调用（或定时调用单个服务）
        #                直接修改主机名会导致调用失败，故此处保留当前机器的原主机名
        echo "$ip $new_hostname $(hostname)" >> "$TMP_DIR/$TMP_FILE"
        # 为本机设置主机名
        sudo hostnamectl set-hostname ${new_hostname} --static --transient
    else
        echo "$ip $new_hostname" >> "$TMP_DIR/$TMP_FILE"
    fi
    ((count++))
}

retrieve_node_ssh_info set_hostname

# 如果有新增的内容，更新 /etc/hosts 文件
if [ -s "$TMP_DIR/$TMP_FILE" ]; then
    sudo sed -i "/# HINA-CLOUD START/,/# HINA-CLOUD END/d" "$HOSTS_FILE"  
    echo -e "\n$START_MARKER" | sudo tee -a "$HOSTS_FILE" > /dev/null
    sudo cat "$TMP_DIR/$TMP_FILE" | sudo tee -a "$HOSTS_FILE" > /dev/null
    echo "$END_MARKER" | sudo tee -a "$HOSTS_FILE" > /dev/null
    echo "Initialization complete. Hosts file updated!"
else
    echo "No new entries to add. Hosts file is already up to date."
fi