#!/usr/bin/env bash

# 脚本所在位置
sh_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &> /dev/null && pwd)
cd $sh_dir
source ./base.sh

# 临时修改linux bridge内核参数
cat << EOF | sudo tee /proc/sys/net/bridge/bridge-nf-call-iptables
1
EOF

# 列出k8s所需镜像
sudo kubeadm config images list
# sudo kubeadm config images pull
sudo kubeadm init \
    --ignore-preflight-errors=all \
    --kubernetes-version=v$K8S_DOCKER_IMAGES_VERSION \
    --image-repository=$KUBERNETES_IMAGE_REPOSITORY \
    --service-cidr=$SERVICE_CIDR \
    --pod-network-cidr=$POD_NETWORK_CIDR \
    --v=5

join_command=$(sudo kubeadm token create --print-join-command )
echo "sudo $join_command --ignore-preflight-errors=all" | tee $sh_dir/join-kubernetes.sh

# 在master节点上需要执行的脚本
bash master-kubernetes.sh

# 将加入k8s集群脚本复制到远端，并执行
bash node-authentication.sh
handle_rest_node_ssh_info copy_file_to_remote join-kubernetes.sh
handle_rest_node_ssh_info 'ssh_cmd -p$node_port -n $node_user@$node_ip "bash $node_path/join-kubernetes.sh"'

# sudo kubeadm certs check-expiration

# sudo kubeadm certs renew all

for tar_file in $APP_DOCKER_IMAGES_DIR/master/*.tar; do
   sudo ctr -n k8s.io images import $tar_file
done

# 部署MySQL
if [[ ${SKIP_DEPLOY_MYSQL:-0} -eq 1 ]]; then
    echo "SKIP_DEPLOY_MYSQL is not set to 1, will not deploy mysql!"
else
    bash start-mysql.sh
fi

# 部署redis
if [[ ${SKIP_DEPLOY_REDIS:-0} -eq 1 ]]; then
    echo "SKIP_DEPLOY_REDIS is not set to 1, will not deploy redis!"
else
    bash start-redis.sh
fi

# 部署cloudeon
if [[ ${SKIP_DEPLOY_CLOUDEON:-0} -eq 1 ]]; then
    echo "SKIP_DEPLOY_CLOUDEON is not set to 1, will not deploy cloudeon!"
else
    bash start-cloudeon.sh
fi