#!/usr/bin/env bash

# 脚本所在位置
sh_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &> /dev/null && pwd)
cd $sh_dir
source ./base.sh

mkdir -p $HOME/.kube
sudo cp -i /etc/kubernetes/admin.conf $HOME/.kube/config
sudo chown $(id -u):$(id -g) $HOME/.kube/config

# 获取join命令，默认取第一个网卡的ipv4地址，端口6443
if [[ ${ACQUIRE_JOIN_CMD:-0} -eq 1 ]]; then
    api_server_endpoint=${API_SERVER_ENDPOINT:-$(ifconfig | grep inet -m 1 | awk '{print $2}'):6443}
    join_token=$(kubeadm token list -o jsonpath="{.token}")
    ca_cert_hash=$(openssl x509 -pubkey -in /etc/kubernetes/pki/ca.crt \
        | openssl rsa -pubin -outform der 2>/dev/null \
        | openssl dgst -sha256 -hex | sed 's/^.* //')
    if [[ -z "$join_token" ]]; then
        echo "join_token is not found, join command generate end!"
    else
        join_command="sudo kubeadm join $api_server_endpoint \
                   --token $join_token \
                   --discovery-token-ca-cert-hash sha256:$ca_cert_hash"
        echo $join_command | sudo tee $sh_dir/join-kubernetes.sh
    fi
fi

# 从本地读取flannel和dashboard编排文件
kubectl apply -f $KUBERNETES_YAML_DIR/$KUBERNETES_NETWORK
kubectl apply -f $KUBERNETES_YAML_DIR/$KUBERNETES_DASHBOARD

# 创建dashboard admin账户，并赋予集群管理员角色
kubectl create sa dashboard-admin -n kubernetes-dashboard
kubectl create clusterrolebinding dashboard-cluster-admin \
        --clusterrole=cluster-admin \
        --serviceaccount=kubernetes-dashboard:dashboard-admin

# 设置secret以通过dashboard管理
kubectl apply -f $KUBERNETES_YAML_DIR/$KUBERNETES_DASHBOARD_SECRET

# 等待10秒
count_down 10

dashboard_token=$(kubectl describe secret \
    $(kubectl get sa dashboard-admin -n kubernetes-dashboard \
        -o jsonpath="{.secrets[0].name}") -n kubernetes-dashboard \
    | awk '/token:/ {print $NF}')
echo $dashboard_token | tee dashboard-admin-token

# 去除污点
taint_no=$(kubectl get no -o jsonpath="{.items[0].metadata.name}")
kubectl taint nodes "$taint_no" node-role.kubernetes.io/control-plane:NoSchedule-
