#!/usr/bin/env bash

# 脚本所在位置
sh_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &> /dev/null && pwd)
cd $sh_dir
source ./base.sh

# 删除环境时可以不需要在失败命令处终止，以避免卸载不干净的情况
set +eo pipefail

# 获取操作系统
source /etc/os-release
if [[ -n $DEFAULT_OS ]]; then
    ID=$DEFAULT_OS
fi

autoremove_cmd=""
docker_package_list="docker-ce docker-ce-cli docker-ce-rootless-extras containerd.io slirp4netns"
kubernetes_package_list="kubeadm kubectl kubelet kubernetes-cni cri-tools socat"
expect_package_list="expect tcl"
if [[ $ID == "centos" || $ID_LIKE =~ "rhel" || $ID_LIKE =~ "fedora" ]]; then
    autoremove_cmd="yum autoremove -y"
    docker_package_list="$docker_package_list checkpolicy fuse-overlayfs setools-libs container-selinux audit-libs-python fuse3-libs libcgroup libsemanage-python policycoreutils-python python-IPy"
    kubernetes_package_list="$kubernetes_package_list libnetfilter_cthelper libnetfilter_cttimeout libnetfilter_queue conntrack-tools"
elif [[ $ID == "ubuntu" || $ID_LIKE =~ "debian" ]]; then
    autoremove_cmd="apt-get autoremove -y -o APT::Install-Recommends='false'"
    docker_package_list="$docker_package_list libslirp0 pigz"
    kubernetes_package_list="$kubernetes_package_list conntrack ebtables"
fi

if [[ -z "$autoremove_cmd" ]]; then
    echo "Unsupported operating system! ID: $ID, ID_LIKE: $ID_LIKE"
    exit 1
fi

# 等待5秒
echo "Current os is $PRETTY_NAME. Use \`$autoremove_cmd\` to remove!"
count_down 5

# 根据标志位，跳过k8s卸载步骤
if [[ ${SKIP_UNINSTALL_KUBERNETES:-0} -eq 1 ]]; then
    echo "SKIP_UNINSTALL_KUBERNETES is set to 1, will not uninstall kubernetes!"
else
    sudo kubeadm reset -f
    sudo systemctl disable kubelet --now

    sudo $autoremove_cmd $kubernetes_package_list

    sudo rm -rf ~/.kube
    sudo rm -rf /etc/kubernetes
    sudo rm -rf /var/lib/etcd
    sudo rm -rf /var/lib/kubelet
    sudo rm -rf /etc/cni/net.d
    sudo rm -rf /var/lib/containerd
fi

# 根据标志位，跳过containerd卸载步骤
if [[ ${SKIP_UNINSTALL_CONTAINERD:-0} -eq 1 ]]; then
    echo "SKIP_UNINSTALL_CONTAINERD is set to 1, will not uninstall containerd!"
else
    sudo systemctl disable containerd --now

    sudo $autoremove_cmd $docker_package_list

    count_down 30
    sudo rm -rf /var/lib/containerd
    sudo rm -rf /etc/docker
#     sudo rm -rf /usr/libexec/docker
    sudo rm -rf /var/lib/containerd
fi


if [[ ${SKIP_NODE_SSH_AUTHENTICATION:-0} -eq 1 ]]; then
    echo "SKIP_NODE_SSH_AUTHENTICATION is set to 1, will not uninstall expect"
else
    sudo $autoremove_cmd $expect_package_list
fi


if [[ ${SKIP_DELETE_NODE_APP_DIR:-0} -eq 1 ]]; then
    echo "SKIP_DELETE_NODE_APP_DIR is set to 1, will not delete node application directory!"
else
    # 依次登录目标服务器删除应用目录
    sudo rm -rf /opt/edp
    sudo rm -rf /opt/mysql
    sudo rm -rf /opt/redis
    sudo rm -rf /opt/cloudeon
fi


# 根据标志位，判断是否重启机器
if [[ ${REBOOT_AFTER_REMOVE:-0} -eq 1 ]]; then
    echo "Remove complete, wait 10 seconds to reboot!"
    count_down 10
    sudo reboot
else
    echo "Remove complete, REBOOT_AFTER_REMOVE is not set to 1, will not reboot!"
fi