#!/usr/bin/env bash

# 脚本所在位置
sh_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &> /dev/null && pwd)
cd $sh_dir
source ./base.sh

set +eo pipefail

echo "Start cloudeon..."
# 检查命名空间
check_cloudeon_namespace="$(kubectl get ns | grep $CLOUDEON_NAMESPACE)"
if [[ -z $check_cloudeon_namespace ]]; then
    kubectl create ns $CLOUDEON_NAMESPACE
fi

# 打标签
kubectl label no $(kubectl get no| grep control-plane -m 1| awk '{print $1}') cloudeon=true --overwrite

# 应用部署
sudo sed -i "s/root@123/$MYSQL_ROOT_PASSWORD/g" $KUBERNETES_YAML_DIR/$CLOUDEON_DEPLOYMENT_YAML
REDIS_CLUSTER_ADDRESS=""
retrieve_node_ssh_info 'REDIS_CLUSTER_ADDRESS="$node_ip:6379,$REDIS_CLUSTER_ADDRESS"'
sudo sed -i "s/127.0.0.1:6379/${REDIS_CLUSTER_ADDRESS%,*}/g" $KUBERNETES_YAML_DIR/$CLOUDEON_DEPLOYMENT_YAML
handle_first_node_ssh_info 'echo "Set mysql host to $node_ip"'
sudo sed -i "s/127.0.0.1/$node_ip/g" $KUBERNETES_YAML_DIR/$CLOUDEON_DEPLOYMENT_YAML
kubectl apply -f $KUBERNETES_YAML_DIR/$CLOUDEON_DEPLOYMENT_YAML -n $CLOUDEON_NAMESPACE
echo "wait 30 seconds for cloudeon starting"
sleep 30

# 获取登录token
login_token=$(curl -s http://127.0.0.1:7700/apiPre/acc/doLogin?name=admin\&pwd=admin \
            | grep -E '(\w{8}-\w{4}-\w{4}-\w{4}-\w{12})' -o)

# 调用添加集群接口
kubeconfig=$(cat $HOME/.kube/config)
curl -s http://127.0.0.1:7700/apiPre/cluster/save -X POST \
    -H "Satoken: $login_token" \
    -H 'Content-type: application/json' \
    -d "{\"clusterName\":\"海纳嗨数分析云平台私有化集群\",\"namespace\":\"$CLOUDEON_NAMESPACE\",\"stackId\":1,\"kubeConfig\":\"${kubeconfig//$'\n'/\\n}\"}"

# 根据当前k8s集群中的节点，调用添加节点接口
all_nodes=$(kubectl get no | awk '{print $1}')
privateKeyPath=$NODE_SSH_KEY_PATH
sudo cp -f $privateKeyPath /opt/cloudeon/ssh/id_rsa
privateKeyPathInContainer=/data/appdeploy/cloudeon/ssh/id_rsa
for node in $all_nodes; do
    if [[ ! $node == "NAME" ]]; then
        node_ip=$(kubectl get no $node -o jsonpath="{.status.addresses[0].address}")
        node_hostname=$(kubectl get no $node -o jsonpath="{.status.addresses[1].address}")
        LINE=$(grep "^$node_ip$\|^$node_ip " $NODE_SSH_INFO -m 1)
        line_arg_assign_to_var 2 node_user NODE_SSH_USER
        line_arg_assign_to_var 4 node_port NODE_SSH_PORT
        curl -s http://127.0.0.1:7700/apiPre/node/add -X POST \
            -H "Satoken: $login_token" \
            -H 'Content-type: application/json' \
            -d "{\"ip\":\"$node_ip\",\"hostname\":\"$node_hostname\",\"sshAuthType\":\"PRIVATEKEY\",\"privateKeyPath\":\"$privateKeyPathInContainer\",\"sshPort\":$node_port,\"sshUser\":\"$node_user\",\"clusterId\":1}"
    fi
done

echo ""

handle_first_node_ssh_info 'echo "Cloudeon started, access http://$node_ip:7700/ in browser to continue!"'