#!/usr/bin/env bash

# 脚本所在位置
sh_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &> /dev/null && pwd)
cd $sh_dir
source ./base.sh

set +eo pipefail

echo "Start mysql..."
# 检查命名空间
check_mysql_namespace=$(kubectl get ns | grep $MYSQL_NAMESPACE)
if [[ -z $check_mysql_namespace ]]; then
    kubectl create ns $MYSQL_NAMESPACE
fi

# 打标签
kubectl label no $(kubectl get no| grep control-plane -m 1| awk '{print $1}') mysql=true --overwrite

# 设置字符集和排序规则
sudo mkdir -p /opt/mysql/conf
cat << EOF | sudo tee /opt/mysql/conf/charset.cnf
[mysqld]
character-set-server=utf8mb4
collation-server=utf8mb4_general_ci
max_connections=1000
EOF

# 应用部署，并等待60秒
kubectl apply -f $KUBERNETES_YAML_DIR/$MYSQL_DEPLOYMENT_YAML -n $MYSQL_NAMESPACE
echo "wait 60 seconds for mysql starting"
sleep 60

# 替换密码，并执行初始化脚本
sudo cp -f $MYSQL_INIT_SQL /opt/mysql/conf/
init_sql_script=${MYSQL_INIT_SQL##*/}
sudo chmod 777 /opt/mysql/conf/$init_sql_script
sudo sed -i "s/MYSQL_ROOT_PASSWORD/$MYSQL_ROOT_PASSWORD/g" /opt/mysql/conf/$init_sql_script
kubectl exec -n $MYSQL_NAMESPACE $(kubectl get po -n $MYSQL_NAMESPACE -o jsonpath='{.items[0].metadata.name}') \
  -- mysql -h127.0.0.1 -uroot -proot@123 -e "source /etc/mysql/conf.d/$init_sql_script"

echo "Start mysql over."