#!/usr/bin/env bash

# 脚本所在位置
sh_dir=$(cd "$(dirname "${BASH_SOURCE[0]}")" &> /dev/null && pwd)
cd $sh_dir
source ./base.sh

set +eo pipefail

echo "Start redis cluster..."
# 检查命名空间
check_redis_namespace="$(kubectl get ns | grep $REDIS_NAMESPACE)"
if [[ -z $check_redis_namespace ]]; then
    kubectl create ns $REDIS_NAMESPACE
fi

# 打标签
kubectl label no $(kubectl get no| grep Ready -m 3| awk '{print $1}') redis-cluster=true --overwrite

# 应用部署
kubectl apply -f $KUBERNETES_YAML_DIR/$REDIS_DEPLOYMENT_YAML -n $REDIS_NAMESPACE
count_down 10

# 组成集群
kubectl exec -n $REDIS_NAMESPACE $(kubectl get po -n $REDIS_NAMESPACE -o jsonpath='{.items[0].metadata.name}') \
    -- redis-cli --cluster create --cluster-replicas 0 \
    $(kubectl get po -n $REDIS_NAMESPACE -o jsonpath='{range.items[*]}{.status.podIP}:6379 {end}') \
    --cluster-yes

echo "Start redis cluster over."